@@ -2,7 +2,6 @@ import importlib
 import importlib.util
 from typing import Union, Text
 
-from pyms.constants import SERVICE_BASE
 from pyms.exceptions import PackageNotExists
 
 
@@ -11,10 +10,6 @@ def import_from(module: Text, name: Text):
     return getattr(module, name)
 
 
-def get_service_name(service_base=SERVICE_BASE, service=""):
-    return ".".join([service_base, service])
-
-
 def import_package(package: Text):
     return importlib.import_module(package)
 
